@@ -53,10 +53,10 @@ char       *string_firstword(char **str);           /* returns new string   */
 void        string_format(String *sp, char const *fmt, ...)
             ATTRIBUTE_FORMAT_PRINTF(2, 3);
 char        string_popfront(String *sp);
-char       *string_release(String *sp);     /* returns interal str          */
+char       *string_release(String *sp);     /* returns internal str          */
                                             /* reassigning text OK          */
 
-char       *string_grab(String **sp);       /* returns interal str          */
+char       *string_grab(String **sp);       /* returns internal str          */
                                             /* *sp = 0             .        */
 
 void        string_replace(String *sp, char const *srch, char const *replace);
